[gedit] file-chooser: Hint at possibility to open multiple files



commit 10b20e2b9b5eddcac1e2e4dc8b41c167630fa5f3
Author: p3732 <p3732 users noreply github com>
Date:   Thu Mar 12 14:53:47 2020 +0100

    file-chooser: Hint at possibility to open multiple files
    
    Change the title of the file chooser dialog to use the plural
    of the word files, to point out that several files can be opened
    at the same time.

 gedit/gedit-commands-file.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gedit/gedit-commands-file.c b/gedit/gedit-commands-file.c
index 9580e5933..20759c8b8 100644
--- a/gedit/gedit-commands-file.c
+++ b/gedit/gedit-commands-file.c
@@ -447,8 +447,8 @@ _gedit_cmd_file_open (GSimpleAction *action,
                }
        }
 
-       /* Translators: "Open" is the title of the file chooser window. */
-       open_dialog = gedit_file_chooser_dialog_create (C_("window title", "Open"),
+       /* Translators: "Open Files" is the title of the file chooser window. */
+       open_dialog = gedit_file_chooser_dialog_create (C_("window title", "Open Files"),
                                                        window != NULL ? GTK_WINDOW (window) : NULL,
                                                        GEDIT_FILE_CHOOSER_OPEN |
                                                        GEDIT_FILE_CHOOSER_ENABLE_ENCODING |


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]